@@ -1,7 +1,4 @@
 /***************************************************************************
-
-                          orbitswidget.cpp  -  description
-                             -------------------
     begin                : Jun 23 2003
     copyright            : (C) 2003, 2004, 2005 by Carsten Niehaus
     email                : cniehaus@kde.org
@@ -18,13 +15,20 @@
 
 #include "orbitswidget.h"
 
+#include <kdebug.h>
+
 //QT-Includes
 #include <qpainter.h>
 #include <qregexp.h>
+#include <qpixmap.h>
 
-OrbitsWidget::OrbitsWidget( const int ElemNo , QWidget *parent, const char *name) : QWidget( parent, name )
+OrbitsWidget::OrbitsWidget( QWidget *parent, const char *name) : QWidget( parent, name )
 {
-	Elemno = ElemNo;
+}
+
+void OrbitsWidget::setElementNumber( const int num )
+{
+	Elemno = num;
 	
 	hulllist.append( "1" );
 	hulllist.append( "2" );     //Helium
@@ -136,6 +140,7 @@ OrbitsWidget::OrbitsWidget( const int ElemNo , QWidget *parent, const char *name
 	hulllist.append( "2 8 18 32 32 14 2" );	
 	hulllist.append( "2 8 18 32 32 15 2" );//Mt
 	hulllist.append( "2 8 18 32 32 16 2" );//Darmstadtium
+	hulllist.append( "2 8 18 32 32 17 2" );//Roentgenium
 	
 	getNumberOfOrbits();	
 }
@@ -201,6 +206,8 @@ void OrbitsWidget::paintEvent(  QPaintEvent* )
 	else r = ( w-2*w_c )/2;
 	
 	r_electron = r/20; //diameter of an electron-circle
+		
+	QBrush   brush(  yellow );
 	
 	int d = 2*r; //Diameter
 	int	ddx = d/(2*num);//difference to the previous circle
@@ -211,15 +218,17 @@ void OrbitsWidget::paintEvent(  QPaintEvent* )
 
 	for ( int i = 0 ; i < num ; ++i )
 	{
-		DC.setBrush( Dense7Pattern  );
-
 		int mx = w_c+ddx*i; //the x-coordinate for the current circle
 		int my = h_c+ddx*i; //the y-coordinate for the current circle
 
+		DC.setBrush(  NoBrush );
+		DC.setPen(  black ); 
+		
 		//draw the big ellipses in concentric circles
 		DC.drawEllipse( mx , my , d , d);
 
-		DC.setBrush( Qt::SolidPattern );
+		DC.setBrush( brush );
+		
 		for ( int e = 0 ; e < *it ; ++e )
 		{
 			int x = (int)translateToDX(  ( double )d/2 , ( double )e , *it);
@@ -229,6 +238,7 @@ void OrbitsWidget::paintEvent(  QPaintEvent* )
 					y + mx + d/2 - r_electron,
 					2*r_electron ,
 					2*r_electron );
+			
 		}
 		--it;
 		d = d-2*ddx;
