@@ -85,7 +85,7 @@ void KEducaPrefs::configRead()
     KConfig *config = KGlobal::config();
     config->setGroup("Options");
     QSize defaultSize(500,400);
-    this->resize( config->readSizeEntry("Geometry", &defaultSize ) );
+    resize( config->readSizeEntry("Geometry", &defaultSize ) );
     config->readBoolEntry("ResultFinish", true ) ? _resultAfterFinish->setChecked(true) : _resultAfterNext->setChecked(true);
     config->readBoolEntry("RandomQuestions", false ) ? _randomQuestions->setChecked(true) : _randomQuestions->setChecked(false);
     config->readBoolEntry("RandomAnswers", false ) ? _randomAnswers->setChecked(true) : _randomAnswers->setChecked(false);
@@ -96,7 +96,7 @@ void KEducaPrefs::configWrite()
 {
     KConfig *config = KGlobal::config();
     config->setGroup("Options");
-    config->writeEntry("Geometry", this->size() );
+    config->writeEntry("Geometry", size() );
     config->writeEntry("ResultFinish", _resultAfterFinish->isChecked() );
     config->writeEntry("RandomQuestions", _randomQuestions->isChecked() );
     config->writeEntry("RandomAnswers", _randomAnswers->isChecked() );
@@ -107,6 +107,6 @@ void KEducaPrefs::configWrite()
 void KEducaPrefs::slotOk()
 {
     configWrite();
-    this->accept();
+    accept();
 }
 
