@@ -1,4 +1,3 @@
-// aboutdata.h
 // Copyright (C)  2002  Dominique Devriese <devriese@kde.org>
 
 // This program is free software; you can redistribute it and/or
@@ -13,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include <kaboutdata.h>
 #include <klocale.h>
@@ -28,10 +27,10 @@ inline KAboutData* kigAboutData( const char* name, const char* iname )
 
   KAboutData* tmp = new KAboutData( name, iname, version,
 				   description, KAboutData::License_GPL,
-				   I18N_NOOP( "(C) 2002-2004, The Kig developers" ),
+				   I18N_NOOP( "(C) 2002-2005, The Kig developers" ),
 				   0, "http://edu.kde.org/kig" );
   tmp->addAuthor("Dominique Devriese",
-                 I18N_NOOP("Original author, maintenance, design and lots of code."),
+                 I18N_NOOP("Original author, long time maintainer, design and lots of code."),
 		  "devriese@kde.org" );
 
   tmp->addAuthor("Maurizio Paolini",
@@ -40,19 +39,18 @@ inline KAboutData* kigAboutData( const char* name, const char* iname )
                             "transformations and property tests support." ),
 		 "paolini@dmf.bs.unicatt.it");
 
+  tmp->addAuthor( "Pino Toscano",
+                  I18N_NOOP( "Actual maintainer, Dr. Geo import filter, point and "
+                             "line styles, Italian translation, "
+                             "miscellaneous stuff here and there." ),
+                  "toscano.pino@tiscali.it" );
+
   tmp->addAuthor( "Franco Pasquarelli",
                   I18N_NOOP( "Helped a lot with the implementation of the Locus object, "
                              "there's quite some math involved in doing it right, and "
                              "Franco wrote the most difficult parts." ),
                   "pasqui@dmf.bs.unicatt.it" );
 
-  tmp->addAuthor( "Pino Toscano",
-                  I18N_NOOP( "Worked on the Dr. Geo import filter, point and "
-                             "line styles and the Italian translations, "
-                             "also gave me lots of useful feedback, "
-                             "like feature requests and bug reports." ),
-                  "toscano.pino@tiscali.it" );
-
   tmp->addCredit( "Eric Depagne",
                   I18N_NOOP( "The French translator, who also sent me some useful "
                              "feedback, like feature requests and bug reports." ),
@@ -60,7 +58,7 @@ inline KAboutData* kigAboutData( const char* name, const char* iname )
 
   tmp->addCredit("Marc Bartsch",
 		  I18N_NOOP("Author of KGeo, where I got inspiration, "
-			    "some source, and most of the artwork from"),
+			    "some source, and most of the artwork from." ),
 		  "marc.bartsch@web.de");
 
   tmp->addCredit("Christophe Devriese",
@@ -80,11 +78,12 @@ inline KAboutData* kigAboutData( const char* name, const char* iname )
                  "robertgogolok@gmx.de");
 
   tmp->addCredit("David Vignoni",
-                 I18N_NOOP("Responsible for the nice SVG Icon" ),
+                 I18N_NOOP("Responsible for the nice application SVG Icon." ),
                  "david80v@tin.it");
 
-  tmp->setTranslator( I18N_NOOP( "_: NAME OF TRANSLATORS\\nYour names" ),
-                      I18N_NOOP( "_: EMAIL OF TRANSLATORS\\nYour emails" ) );
+  tmp->addCredit( "Danny Allen",
+                  I18N_NOOP( "Resonsible for the new object action icons." ),
+                  "danny@dannyallen.co.uk" );
 
   return tmp;
 }
