@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "construct_mode.h"
 
@@ -33,6 +33,8 @@
 #include "../misc/kigpainter.h"
 #include "../misc/calcpaths.h"
 
+#include "popup.h"
+
 #include <kcursor.h>
 #include <kaction.h>
 
@@ -60,6 +62,42 @@ BaseConstructMode::~BaseConstructMode()
 //  delete mcursorholder;
 }
 
+void BaseConstructMode::leftReleased( QMouseEvent* e, KigWidget* v )
+{
+  if( (pointLocation() - e->pos()).manhattanLength() > 4 ) return;
+
+  ObjectHolder* o = 0;
+  bool keyCtrlOrShift = ( e->state() & ( ControlButton | ShiftButton) ) != 0;
+  std::vector<ObjectHolder*> moco = oco();
+  if ( ! moco.empty() )
+  {
+    std::vector<ObjectHolder*> goodargs;
+    if ( !moco.empty() )
+    {
+      std::vector<ObjectHolder*>::const_iterator it;
+      std::vector<ObjectCalcer*> testargs = getCalcers( mparents );
+      for ( std::vector<ObjectHolder*>::const_iterator i = moco.begin(); i != moco.end(); ++i )
+      {
+        it = std::find( mparents.begin(), mparents.end(), *i );
+        bool newdup =
+            ( it == mparents.end() ) || 
+            isAlreadySelectedOK( testargs, it - mparents.begin() );
+        if ( newdup )
+        {
+          testargs.push_back( ( *i )->calcer() );
+          if ( wantArgs( testargs, mdoc.document(), *v ) )
+            goodargs.push_back( *i );
+          testargs.pop_back();
+        }
+      }
+      int id = ObjectChooserPopup::getObjectFromList( e->pos(), v, goodargs );
+      if ( id >= 0 )
+        o = goodargs[id];
+    }
+  }
+  leftClickedObject( o, e->pos(), *v, keyCtrlOrShift );
+}
+
 void BaseConstructMode::leftClickedObject(
   ObjectHolder* o, const QPoint& p, KigWidget& w, bool )
 {
@@ -153,16 +191,34 @@ void BaseConstructMode::mouseMoved( const std::vector<ObjectHolder*>& os, const
 
   std::vector<ObjectCalcer*> args = getCalcers( mparents );
   bool duplicationchecked = false;
+  std::vector<ObjectHolder*> goodargs;
   if ( ! os.empty() )
   {
-    std::vector<ObjectHolder*>::iterator it 
-          = std::find( mparents.begin(), mparents.end(), os.front() );
-    duplicationchecked = 
+    std::vector<ObjectHolder*>::const_iterator it;
+    std::vector<ObjectCalcer*> testargs = getCalcers( mparents );
+    for ( std::vector<ObjectHolder*>::const_iterator i = os.begin(); i != os.end(); ++i )
+    {
+      it = std::find( mparents.begin(), mparents.end(), *i );
+      bool newdup =
           ( it == mparents.end() ) || 
           isAlreadySelectedOK( args, it - mparents.begin() );
-    if ( duplicationchecked ) args.push_back( os.front()->calcer() );
+      if ( newdup )
+      {
+        testargs.push_back( ( *i )->calcer() );
+        if ( wantArgs( testargs, mdoc.document(), w ) )
+          goodargs.push_back( *i );
+        testargs.pop_back();
+      }
+      duplicationchecked |= newdup;
+    }
   }
-  if ( !os.empty() && duplicationchecked && wantArgs( args, mdoc.document(), w ) )
+  bool calcnow = ( goodargs.size() == 1 ) || ( ( goodargs.size() > 0 ) && ( goodargs.front()->imp()->inherits( PointImp::stype() ) ) );
+  if ( calcnow )
+  {
+    args.push_back( goodargs.front()->calcer() );
+  }
+
+  if ( !os.empty() && duplicationchecked && calcnow )
   {
     handlePrelim( args, p, pter, w );
 
@@ -174,6 +230,7 @@ void BaseConstructMode::mouseMoved( const std::vector<ObjectHolder*>& os, const
     args.push_back( mpt.get() );
     std::vector<ObjectCalcer*> argscursor = getCalcers( mparents );
     argscursor.push_back( mcursor );
+    bool text = true;
     if ( wantArgs( args, mdoc.document(), w ) )
     {
       ObjectDrawer d;
@@ -195,6 +252,18 @@ void BaseConstructMode::mouseMoved( const std::vector<ObjectHolder*>& os, const
     else
     {
       w.setCursor( KCursor::arrowCursor() );
+      text = false;
+    }
+    if ( !text && ( goodargs.size() > 1 ) )
+    {
+      QString strwhich = i18n( "Which object?" );
+      mdoc.emitStatusBarText( strwhich );
+
+      QPoint textloc = p;
+      textloc.setX( textloc.x() + 15 );
+      pter.drawTextStd( textloc, strwhich );
+
+      w.setCursor( KCursor::handCursor() );
     }
   }
   w.updateWidget( pter.overlay() );
