@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #ifndef KIG_MODES_CONSTRUCT_MODE_H
 #define KIG_MODES_CONSTRUCT_MODE_H
@@ -29,8 +29,10 @@ class ObjectCalcer;
 class PointConstructMode
   : public BaseMode
 {
-  // this is the point that we move around, for the user to add
-  // somewhere..
+  /**
+   * this is the point that we move around, for the user to add
+   * somewhere..
+   */
   ObjectTypeCalcer::shared_ptr mpt;
 public:
   PointConstructMode( KigPart& d );
@@ -51,14 +53,19 @@ protected:
 class BaseConstructMode
   : public BaseMode
 {
-  // this is the point that we move around, in case the user wants to
-  // add a point somewhere..
+  /**
+   * this is the point that we move around, in case the user wants to
+   * add a point somewhere..
+   */
   ObjectTypeCalcer::shared_ptr mpt;
-  // mp: this point always follows the cursor
-  // IMPORTANT: this Calcer must NEVER be added to the document, since
-  // its is used in constructors that need more input from the user
-  // to decide parameters of the constructed object that will be fixed
-  // afterwards (like the number of sides of a regular polygon)
+  /**
+   * mp: this point always follows the cursor
+   *
+   * IMPORTANT: this Calcer must NEVER be added to the document, since
+   * its is used in constructors that need more input from the user
+   * to decide parameters of the constructed object that will be fixed
+   * afterwards (like the number of sides of a regular polygon)
+   */
   ObjectTypeCalcer* mcursor;
   // we also allocate here the corresponding objectholder, since the
   // only sensible place where to deallocate it is in the destructor
@@ -66,6 +73,8 @@ class BaseConstructMode
 //  ObjectHolder* mcursorholder;
   std::vector<ObjectHolder*> mparents;
 
+  void leftReleased( QMouseEvent* e, KigWidget* v );
+
 public:
   void selectObject( ObjectHolder* o, KigWidget& w );
   void selectObjects( const std::vector<ObjectHolder*>& os, KigWidget& w );
