@@ -14,7 +14,7 @@
 
  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
- Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
+ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301
  USA
 **/
 
@@ -32,6 +32,7 @@
 #include "../objects/line_imp.h"
 #include "../objects/other_type.h"
 #include "../objects/object_factory.h"
+#include "../objects/polygon_imp.h"
 #include "../misc/lists.h"
 #include "../misc/argsparser.h"
 #include "../misc/kigpainter.h"
@@ -50,6 +51,7 @@
 #include <qregexp.h>
 #include <qvalidator.h>
 
+#include <kaction.h>
 #include <kcolordialog.h>
 #include <kglobal.h>
 #include <kiconloader.h>
@@ -228,7 +230,7 @@ NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
   mproviders.push_back( new ScriptActionsProvider() );
 #endif
 
-  for ( int i = 0; i < (int) NumberOfMenus; ++i )
+  for ( uint i = 0; i < NumberOfMenus; ++i )
     mmenus[i] = new QPopupMenu( this );
 
   connect( mmenus[TransformMenu], SIGNAL( activated( int ) ),
@@ -275,7 +277,7 @@ NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
       "test",
       QString::null,
       "launch",
-      "text",
+      "kig_text",
       "color_fill",
 //      "colorize",
       "sizer",
@@ -292,9 +294,7 @@ NormalModePopupObjects::NormalModePopupObjects( KigPart& part,
     else
     {
       KIconLoader* l = part.instance()->iconLoader();
-      QPixmap icon = l->loadIcon( menuicons[i], KIcon::User, 0, KIcon::DefaultState, 0L, true );
-      if ( icon.isNull() )
-        icon = l->loadIcon( menuicons[i], KIcon::Toolbar );
+      QPixmap icon = l->loadIcon( menuicons[i], KIcon::Small, 22, KIcon::DefaultState, 0L, true );
       insertItem( QIconSet( icon ), menunames[i], mmenus[i], i, index++ );
     }
   };
@@ -384,7 +384,7 @@ void BuiltinObjectActionsProvider::fillUpMenu( NormalModePopupObjects& popup, in
       popup.addAction( menu, i18n( "&Show" ), nextfree+1 );
     }
     nextfree += 2;
-    QPixmap p = l->loadIcon( "move", KIcon::User );
+    QPixmap p = l->loadIcon( "move", KIcon::Toolbar );
     popup.addAction( menu, p, i18n( "&Move" ), nextfree++ );
     p = l->loadIcon( "editdelete", KIcon::Toolbar );
     popup.addAction( menu, p, i18n( "&Delete" ), nextfree++ );
@@ -640,7 +640,9 @@ bool BuiltinObjectActionsProvider::executeAction(
       color = *colors[id];
     else
     {
-      int result = KColorDialog::getColor( color );
+      if ( os.size() == 1 )
+        color = os.front()->drawer()->color();
+      int result = KColorDialog::getColor( color, &w );
       if ( result != KColorDialog::Accepted ) return true;
     }
     KigCommand* kc = new KigCommand( doc, i18n( "Change Object Color" ) );
@@ -741,7 +743,7 @@ void ObjectConstructorActionsProvider::fillUpMenu( NormalModePopupObjects& popup
       QCString iconfile = (*i)->iconFileName();
       if ( !iconfile.isEmpty() && !iconfile.isNull() )
       {
-        QPixmap icon = popup.part().instance()->iconLoader()->loadIcon( iconfile, KIcon::User );
+        QPixmap icon = popup.part().instance()->iconLoader()->loadIcon( iconfile, KIcon::Toolbar, 22, KIcon::DefaultState, 0L, true );
         popup.addAction( menu, icon, (*i)->descriptiveName(), nextfree++ );
       }
       else
@@ -866,7 +868,7 @@ void PropertiesActionsProvider::fillUpMenu( NormalModePopupObjects& popup,
     {
       if ( iconfile && *iconfile )
       {
-        QPixmap pix = popup.part().instance()->iconLoader()->loadIcon( iconfile, KIcon::User );
+        QPixmap pix = popup.part().instance()->iconLoader()->loadIcon( iconfile, KIcon::Toolbar, 22, KIcon::DefaultState, 0L, true );
         popup.addAction( menu, pix, i18n( o->imp()->properties()[i] ), nextfree++ );
       }
       else
@@ -962,14 +964,11 @@ void BuiltinDocumentActionsProvider::fillUpMenu( NormalModePopupObjects& popup,
 {
   if ( menu == NormalModePopupObjects::ToplevelMenu )
   {
-    popup.addAction( menu, i18n( "Unhide &All" ), nextfree++ );
-    KIconLoader* l = popup.part().instance()->iconLoader();
-    QPixmap p = l->loadIcon( "viewmag+", KIcon::Toolbar );
-    popup.addAction( menu, p, i18n( "Zoom &In" ), nextfree++ );
-    p = l->loadIcon( "viewmag-", KIcon::Toolbar );
-    popup.addAction( menu, p, i18n( "Zoom &Out" ), nextfree++ );
-    p = l->loadIcon( "window_fullscreen", KIcon::Toolbar );
-    popup.addAction( menu, p, i18n( "Toggle &Full Screen Mode" ), nextfree++ );
+    popup.addAction( menu, i18n( "U&nhide All" ), nextfree++ );
+    popup.part().action( "view_zoom_in" )->plug( &popup );
+    popup.part().action( "view_zoom_out" )->plug( &popup );
+    popup.part().action( "fullscreen" )->plug( &popup );
+    nextfree += 3;
   }
   else if ( menu == NormalModePopupObjects::SetCoordinateSystemMenu )
   {
@@ -986,32 +985,18 @@ void BuiltinDocumentActionsProvider::fillUpMenu( NormalModePopupObjects& popup,
 bool BuiltinDocumentActionsProvider::executeAction(
   int menu, int& id, const std::vector<ObjectHolder*>&,
   NormalModePopupObjects&,
-  KigPart& doc, KigWidget& w, NormalMode& m )
+  KigPart& doc, KigWidget&, NormalMode& m )
 {
   if ( menu == NormalModePopupObjects::ToplevelMenu )
   {
+    kdDebug() << "id: " << id << endl;
     if ( id == 0 )
     {
       doc.showHidden();
       m.clearSelection();
       return true;
     }
-    else if ( id == 1 )
-    {
-      w.slotZoomIn();
-      return true;
-    }
-    else if ( id == 2 )
-    {
-      w.slotZoomOut();
-      return true;
-    }
-    else if ( id == 3 )
-    {
-      w.view()->toggleFullScreen();
-      return true;
-    }
-    id -= 4;
+    id -= 1;
     return false;
   }
   else if ( menu == NormalModePopupObjects::SetCoordinateSystemMenu )
@@ -1041,7 +1026,7 @@ void ScriptActionsProvider::fillUpMenu( NormalModePopupObjects& popup, int menu,
   if ( menu == NormalModePopupObjects::StartMenu )
   {
     KIconLoader* l = popup.part().instance()->iconLoader();
-    QPixmap p = l->loadIcon( ScriptType::icon( ScriptType::Python ), KIcon::User );
+    QPixmap p = l->loadIcon( ScriptType::icon( ScriptType::Python ), KIcon::Toolbar, 22, KIcon::DefaultState, 0L, true );
     popup.addAction( menu, p, i18n( "Python Script" ), nextfree++ );
     mns++;
   }
@@ -1075,3 +1060,87 @@ bool ScriptActionsProvider::executeAction(
   return false;
 }
 #endif
+
+int ObjectChooserPopup::getObjectFromList( const QPoint& p, KigWidget* w,
+                                           const std::vector<ObjectHolder*>& objs,
+                                           bool givepopup )
+{
+  int size = objs.size();
+
+  // no objects
+  if ( size == 0 )
+    return -1;
+
+  int id = -1;
+
+  int numpoints = 0;
+  int numpolygons = 0;
+  int numothers = 0;
+
+  for ( std::vector<ObjectHolder*>::const_iterator i = objs.begin();
+        i != objs.end(); ++i )
+  {
+    if ( (*i)->imp()->inherits( PointImp::stype() ) ) numpoints++;
+    else if ( (*i)->imp()->inherits( PolygonImp::stype() ) ) numpolygons++;
+    else numothers++;
+  }
+
+  // simply cases:
+  // - only 1 point ( and eventually other objects )
+  // - no points and an object which is not a polygon
+  // - only one object
+  // FIXME: we assume that our objects are sorted ( points, others, polygons )!
+  if ( ( numpoints == 1 ) ||
+       ( ( numpoints == 0 ) && ( numothers == 1 ) ) ||
+       ( size == 1 ) )
+    id = 0;
+  else
+  {
+    if ( givepopup )
+    {
+      ObjectChooserPopup* ppp = new ObjectChooserPopup( p, *w, objs );
+      ppp->exec( QCursor::pos() );
+
+      id = ppp->mselected;
+
+      delete ppp;
+      ppp = 0;
+    }
+    else
+    {
+      // we don't want to show a popup to the user, so let's give a
+      // value > 0 to indicate that it's not the first
+      id = 1;
+    }
+  }
+//  kdDebug() << "numpoints: " << numpoints << endl
+//            << "numothers: " << numothers << endl
+//            << "numpolygons: " << numpolygons << endl
+//            << "id: " << id << endl;
+
+  return id;
+}
+
+ObjectChooserPopup::ObjectChooserPopup( const QPoint& p, KigWidget& view,
+                                        const std::vector<ObjectHolder*>& objs )
+  : KPopupMenu(), mplc( p ), mview( view ), mobjs( objs ), mselected( -1 )
+{
+  for ( uint i = 0; i < mobjs.size(); i++ )
+  {
+    insertItem( !mobjs[i]->name().isEmpty()
+                ? QString::fromLatin1( "%1 %2" ).arg( mobjs[i]->imp()->type()->translatedName() ).arg( mobjs[i]->name() )
+                : mobjs[i]->imp()->type()->translatedName(),
+                i );
+  }
+
+  connect( this, SIGNAL( activated( int ) ), this, SLOT( actionActivatedSlot( int ) ) );
+}
+
+ObjectChooserPopup::~ObjectChooserPopup()
+{
+}
+
+void ObjectChooserPopup::actionActivatedSlot( int which )
+{
+  mselected = which;
+}
