@@ -12,8 +12,8 @@
 
 // You should have received a copy of the GNU General Public License
 // along with this program; if not, write to the Free Software
-// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
-// 02111-1307, USA.
+// Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
+// 02110-1301, USA.
 
 #include "cubic_imp.h"
 
@@ -302,13 +302,13 @@ const ObjectImpType* CubicImp::impRequirementForProperty( uint which ) const
 
 const char* CubicImp::iconForProperty( uint which ) const
 {
-	int pnum = 0;
+  int pnum = 0;
   if ( which < Parent::numberOfProperties() )
     return Parent::iconForProperty( which );
   if ( which == Parent::numberOfProperties() + pnum++ )
-    return "text"; // cartesian equation string
+    return "kig_text"; // cartesian equation string
   else 
-		assert( false );
+    assert( false );
   return "";
 }
 
