@@ -17,13 +17,13 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.     */
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.     */
 
 /* Changed: ignore all rc stuff. use args 1 and 2 for input/output file.
   -- jason */
 
 #include <config.h>
-#include <sys/types.h>
+#include <inttypes.h>
 #include <sys/stat.h>
 #include <unistd.h>
 #include <stdio.h>
@@ -66,7 +66,7 @@ int alphaoreuc(unsigned char x);
 
 int stringcomp(unsigned char *s1, unsigned char *s2)
 {
-	int i;
+	uint i;
 	unsigned char c1,c2;
 
 	for(i = 0; i < strlen(s1);i++) 
@@ -186,7 +186,7 @@ unsigned char **argv;
 /* generate index for *every* kanji in key */
 				i = 2;
 				if (currstr[0] == 0x8f) i++;
-				for ( ; i < strlen(currstr); i+=2)
+				for ( ;  i < strlen(currstr);  i+=2)
 				{
 					if((currstr[i] >= 0xb0) || (currstr[i] == 0x8f))
 					{
@@ -225,7 +225,7 @@ unsigned char **argv;
 				  {
 					  for (isc = 0; isc <= excount; isc++)
 					  {
-						  if (( exlens[isc] == strlen(currstr)) &&
+						  if (( (uint) exlens[isc] == strlen(currstr)) &&
 						  (stringcomp(currstr,exlist[isc]) == 0)   )
 						  {
 							  indptr--;
