@@ -19,7 +19,7 @@
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
-* Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 */
 
@@ -56,7 +56,7 @@
 #include "settingspagefonts.h"
 #include "settingspageprecision.h"
 #include "settingspagescaling.h"
-#include "sliderwindow.h"
+#include "ksliderwindow.h"
 
 class XParser;
 class KmPlotIO;
@@ -110,6 +110,7 @@ MainDlg::MainDlg(QWidget *parentWidget, const char *, QObject *parent, const cha
 	// User edited the configuration - update your local copies of the
 	// configuration data
 	connect( m_settingsDialog, SIGNAL( settingsChanged() ), this, SLOT(updateSettings() ) );
+    connect( view, SIGNAL( resetZoom() ), this, SLOT(resetZoom() ) );
 }
 
 MainDlg::~MainDlg()
@@ -139,14 +140,14 @@ void MainDlg::setupActions()
 	( void ) new KAction( i18n( "E&xport..." ), 0, this, SLOT( slotExport() ), actionCollection(), "export");
 
 	//zoom menu
-	KRadioAction * mnuNoZoom = new KRadioAction(i18n("&No Zoom") ,"CTRL+0",view, SLOT( mnuNoZoom_clicked() ),actionCollection(),"no_zoom" );
+	m_mnuNoZoom = new KRadioAction(i18n("&No Zoom") ,"CTRL+0",view, SLOT( mnuNoZoom_clicked() ),actionCollection(),"no_zoom" );
 	KRadioAction * mnuRectangular = new KRadioAction(i18n("Zoom &Rectangular"), "viewmagfit", "CTRL+1",view, SLOT( mnuRectangular_clicked() ),actionCollection(),"zoom_rectangular" );
 	KRadioAction * mnuZoomIn = new KRadioAction(i18n("Zoom &In"), "viewmag+", "CTRL+2",view, SLOT( mnuZoomIn_clicked() ),actionCollection(),"zoom_in" );
 	KRadioAction * mnuZoomOut = new KRadioAction(i18n("Zoom &Out"), "viewmag-", "CTRL+3",view, SLOT( mnuZoomOut_clicked() ),actionCollection(),"zoom_out" );
 	KRadioAction * mnuZoomCenter = new KRadioAction(i18n("&Center Point") ,"CTRL+4",view, SLOT( mnuCenter_clicked() ),actionCollection(),"zoom_center" );
 	(void ) new KAction(i18n("&Fit Widget to Trigonometric Functions") ,0,view, SLOT( mnuTrig_clicked() ),actionCollection(),"zoom_trig" );
-	mnuNoZoom->setExclusiveGroup("zoom_modes");
-	mnuNoZoom->setChecked(true);
+	m_mnuNoZoom->setExclusiveGroup("zoom_modes");
+    m_mnuNoZoom->setChecked(true);
 	mnuRectangular->setExclusiveGroup("zoom_modes");
 	mnuZoomIn->setExclusiveGroup("zoom_modes");
 	mnuZoomOut->setExclusiveGroup("zoom_modes");
@@ -176,17 +177,17 @@ void MainDlg::setupActions()
 	KAction *mnuYValue =  new KAction( i18n( "&Get y-Value..." ), 0, this, SLOT( getYValue() ), actionCollection(), "yvalue" );
 	KAction *mnuMinValue = new KAction( i18n( "&Search for Minimum Value..." ), "minimum", 0, this, SLOT( findMinimumValue() ), actionCollection(), "minimumvalue" );
 	KAction *mnuMaxValue = new KAction( i18n( "&Search for Maximum Value..." ), "maximum", 0, this, SLOT( findMaximumValue() ), actionCollection(), "maximumvalue" );
-	KAction *mnuArea = new KAction( i18n( "&Area Under Graph..." ), 0, this, SLOT( graphArea() ), actionCollection(), "grapharea" );
+	KAction *mnuArea = new KAction( i18n( "&Calculate Integral" ), 0, this, SLOT( graphArea() ), actionCollection(), "grapharea" );
 
 	connect( m_quickEdit, SIGNAL( returnPressed( const QString& ) ), this, SLOT( slotQuickEdit( const QString& ) ) );
 	KWidgetAction* quickEditAction =  new KWidgetAction( m_quickEdit, i18n( "Quick Edit" ), 0, this, 0, actionCollection(), "quickedit" );
 	quickEditAction->setWhatsThis( i18n( "Enter a simple function equation here.\n"
 	                                     "For instance: f(x)=x^2\nFor more options use Functions->Edit Plots... menu." ) );
 
-	( void ) new KToggleAction( i18n( "Show Slider 1" ), 0, this, SLOT( toggleShowSlider0() ), actionCollection(), QString( "options_configure_show_slider_0" ).latin1() );
-	( void ) new KToggleAction( i18n( "Show Slider 2" ), 0, this, SLOT( toggleShowSlider1() ), actionCollection(), QString( "options_configure_show_slider_1" ).latin1() );
-	( void ) new KToggleAction( i18n( "Show Slider 3" ), 0, this, SLOT( toggleShowSlider2() ), actionCollection(), QString( "options_configure_show_slider_2" ).latin1() );
-	( void ) new KToggleAction( i18n( "Show Slider 4" ), 0, this, SLOT( toggleShowSlider3() ), actionCollection(), QString( "options_configure_show_slider_3" ).latin1() );
+	view->mnuSliders[0] = new KToggleAction( i18n( "Show Slider 1" ), 0, this, SLOT( toggleShowSlider0() ), actionCollection(), QString( "options_configure_show_slider_0" ).latin1() );
+	view->mnuSliders[1] = new KToggleAction( i18n( "Show Slider 2" ), 0, this, SLOT( toggleShowSlider1() ), actionCollection(), QString( "options_configure_show_slider_1" ).latin1() );
+	view->mnuSliders[2] = new KToggleAction( i18n( "Show Slider 3" ), 0, this, SLOT( toggleShowSlider2() ), actionCollection(), QString( "options_configure_show_slider_2" ).latin1() );
+	view->mnuSliders[3] = new KToggleAction( i18n( "Show Slider 4" ), 0, this, SLOT( toggleShowSlider3() ), actionCollection(), QString( "options_configure_show_slider_3" ).latin1() );
 
 	// Popup menu
 	KAction *mnuHide = new KAction(i18n("&Hide") ,0,view, SLOT( mnuHide_clicked() ),actionCollection(),"mnuhide" );
@@ -211,7 +212,7 @@ bool MainDlg::checkModified()
 	if( m_modified )
 	{
 		int saveit = KMessageBox::warningYesNoCancel( m_parent, i18n( "The plot has been modified.\n"
-		             "Do you want to save it?" ) );
+		             "Do you want to save it?" ), QString::null, KStdGuiItem::save(), KStdGuiItem::discard() );
 		switch( saveit )
 		{
 			case KMessageBox::Yes:
@@ -248,7 +249,7 @@ void MainDlg::slotSave()
 
 		if ( oldfileversion)
 		{
-			if ( KMessageBox::warningYesNo( m_parent, i18n( "This file is saved with an old file format; if you save it, you cannot open the file with older versions of Kmplot. Are you sure you want to continue?" ) ) == KMessageBox::No)
+			if ( KMessageBox::warningContinueCancel( m_parent, i18n( "This file is saved with an old file format; if you save it, you cannot open the file with older versions of Kmplot. Are you sure you want to continue?" ), QString::null, i18n("Save New Format") ) == KMessageBox::Cancel)
 				return;
 		}
 		kmplotio->save( m_url.url() );
@@ -275,7 +276,7 @@ void MainDlg::slotSaveas()
 			{
 				m_url = url;
 				m_recentFiles->addURL( url );
-				setWindowCaption( m_url.url() );
+        setWindowCaption( m_url.prettyURL(0, KURL::StripFileProtocol) );
 				m_modified = false;
 			}
 			return;
@@ -353,8 +354,8 @@ bool MainDlg::openFile()
 		return false;
 	}
 	m_currentfile = m_url;
-	m_recentFiles->addURL( m_url  );
-	setWindowCaption( m_url.url() );
+  m_recentFiles->addURL( m_url.prettyURL(0, KURL::StripFileProtocol)  );
+  setWindowCaption( m_url.prettyURL(0, KURL::StripFileProtocol) );
 	m_modified = false;
 	view->updateSliders();
 	view->drawPlot();
@@ -378,12 +379,12 @@ void MainDlg::slotOpenRecent( const KURL &url )
 		m_recentFiles->removeURL(url ); //remove the file from the recent-opened-file-list
 		return;
 	}
+  m_url = m_currentfile = url;
 	m_recentFiles->setCurrentItem(-1); //don't select the item in the open-recent menu
+  setWindowCaption( m_url.prettyURL(0, KURL::StripFileProtocol) );
+  m_modified = false;
 	view->updateSliders();
 	view->drawPlot();
-	m_url = url;
-	setWindowCaption( url.url() );
-	m_modified = false;
 }
 
 void MainDlg::slotPrint()
@@ -711,26 +712,37 @@ void MainDlg::graphArea()
 
 void MainDlg::toggleShowSlider0()
 {
-	if( !view->sliders[ 0 ]->isShown() ) view->sliders[ 0 ]->show();
-	else view->sliders[ 0 ]->hide();
+	toggleShowSlider(0);
 }
 
 void MainDlg::toggleShowSlider1()
 {
-	if( !view->sliders[ 1 ]->isShown() ) view->sliders[ 1 ]->show();
-	else view->sliders[ 1 ]->hide();
+	toggleShowSlider(1);
 }
 
 void MainDlg::toggleShowSlider2()
 {
-	if( !view->sliders[ 2 ]->isShown() ) view->sliders[ 2 ]->show();
-	else view->sliders[ 2 ]->hide();
+	toggleShowSlider(2);
 }
 
 void MainDlg::toggleShowSlider3()
 {
-	if( !view->sliders[ 3 ]->isShown() ) view->sliders[ 3 ]->show();
-	else view->sliders[ 3 ]->hide();
+	toggleShowSlider(3);
+}
+
+void MainDlg::toggleShowSlider(int const num)
+{
+	// create the slider if it not exists already
+	if ( view->sliders[ num ] == 0 )
+	{
+		view->sliders[ num ] = new KSliderWindow( view, num);
+		connect( view->sliders[num]->slider, SIGNAL( valueChanged( int ) ), view, SLOT( drawPlot() ) );
+		connect( view->sliders[num], SIGNAL( windowClosed( int ) ), view, SLOT( sliderWindowClosed(int) ) );
+	}
+	if ( !view->sliders[ num ]->isShown() )
+		view->sliders[ num ]->show();
+	else
+		view->sliders[ num ]->hide();
 }
 
 void MainDlg::setReadOnlyStatusBarText(const QString &text)
@@ -748,6 +760,11 @@ void MainDlg::optionsConfigureToolbars()
 	KApplication::kApplication()->dcopClient()->send(KApplication::kApplication()->dcopClient()->appId(), "KmPlotShell","optionsConfigureToolbars()", QByteArray());
 }
 
+void MainDlg::resetZoom()
+{
+  m_mnuNoZoom->activate();
+}
+
 // It's usually safe to leave the factory code alone.. with the
 // notable exception of the KAboutData data
 #include <kaboutdata.h>
