@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with this library; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 
 #endif
 
@@ -96,6 +96,24 @@ struct _xml_att {
     struct _xml_ele *ce;	/* containing element */
 };
 
+/* default memory managers, override with xmlMalloc() */
+static void *(*mymalloc)(size_t size) = malloc;
+static void *(*myrealloc)(void *ptr, size_t size) = realloc;
+static void (*myfree)(void *ptr) = free;
+
+/* install new version of malloc/realloc/free.
+ * N.B. don't call after first use of any other lilxml function
+ */
+void
+xmlMalloc (void *(*newmalloc)(size_t size),
+	   void *(*newrealloc)(void *ptr, size_t size),
+	   void (*newfree)(void *ptr))
+{
+	mymalloc = newmalloc;
+	myrealloc = newrealloc;
+	myfree = newfree;
+}
+
 /* pass back a fresh handle for use with our other functions */
 LilXML *
 newLilXML ()
@@ -742,5 +760,3 @@ main (int ac, char *av[])
 }
 #endif
 
-/* For RCS Only -- Do Not Edit */
-static char *rcsid[2] = {(char *)rcsid, "@(#) $RCSfile$ $Date: 2005-02-15 19:02:40 +0100 (Di, 15 Feb 2005) $ $Revision: 389685 $ $Name:  $"};
