@@ -114,7 +114,8 @@ LocationDialog::LocationDialog( QWidget* parent )
 	QMap<QString, TimeZoneRule>::Iterator it = p->data()->Rulebook.begin();
 	QMap<QString, TimeZoneRule>::Iterator itEnd = p->data()->Rulebook.end();
 	for ( ; it != itEnd; ++it )
-		TZRuleBox->insertItem( it.key() );
+		if ( it.key().length() )
+			TZRuleBox->insertItem( it.key() );
 
 	ClearFields = new QPushButton( i18n( "Clear Fields" ), CoordBox, "ClearFields" );
 	ShowTZRules = new QPushButton( i18n( "Explain DST Rules" ), CoordBox, "ShowDSTRules" );
@@ -313,6 +314,9 @@ void LocationDialog::changeCity( void ) {
 		for ( int i=0; i<TZRuleBox->count(); ++i ) {
 			if ( p->data()->Rulebook[ TZRuleBox->text(i) ].equals( SelectedCity->tzrule() ) ) {
 				TZRuleBox->setCurrentItem( i );
+		//DEBUG
+		kdDebug() << "tzrule: " << TZRuleBox->text(i) <<":"<<i << endl;
+
 				break;
 			}
 		}
@@ -351,7 +355,7 @@ void LocationDialog::addCity( void ) {
 	} else {
 		if ( !nameModified ) {
 			QString message = i18n( "Really override original data for this city?" );
-			if ( KMessageBox::questionYesNo( 0, message, i18n( "Override existing data?" ) ) == KMessageBox::No )
+			if ( KMessageBox::questionYesNo( 0, message, i18n( "Override Existing Data?" ), i18n("Override Data"), i18n("Do Not Override")) == KMessageBox::No )
 				return; //user answered No.
 		}
 
