@@ -2,8 +2,10 @@
                           skypoint.h  -  K Desktop Planetarium
                              -------------------
     begin                : Sun Feb 11 2001
-    copyright            : (C) 2001 by Jason Harris
+    copyright            : (C) 2001-2005 by Jason Harris
     email                : jharris@30doradus.org
+    copyright            : (C) 2004-2005 by Pablo de Vicente
+    email                : p.devicente@wanadoo.es
  ***************************************************************************/
 
 /***************************************************************************
@@ -244,12 +246,10 @@ public:
 	void HorizontalToEquatorial( const dms* LST, const dms* lat );
 
 	/**@short Convert Right Ascension/Declination to Ecliptic logitude/latitude.
-	*@param Obliquity current Obliquity of the Ecliptic (angle from Equator)
 	*/
 	void EquatorialToEcliptic( const KSNumbers *num );
 
 	/**@short Convert Ecliptic logitude/latitude to Right Ascension/Declination.
-	*@param Obliquity current Obliquity of the Ecliptic (angle from Equator)
 	*/
 
 	void EclipticToEquatorial( const KSNumbers *num );
@@ -381,13 +381,92 @@ public:
 	 *  is small.
 	 *  Meeus provides a different algorithm in page 111 which we 
 	 *  implement here.
-	 *  @param SkyPoint to which distance is to be calculated
+	 *  @param sp SkyPoint to which distance is to be calculated
 	 *  @return dms angle representing angular separation.
 	 **/
 
 	dms angularDistanceTo( SkyPoint *sp);
 
 	bool operator == ( SkyPoint &p ) { return ( ra()->Degrees() == p.ra()->Degrees() && dec()->Degrees() == p.dec()->Degrees() ); }
+	
+	/** Computes the velocity of the Sun projected on the direction of the source.
+	 *
+	 * @param jd Epoch expressed as julian day to which the source coordinates refer to.
+	 * @return Radial velocity of the source referred to the barycenter of the solar system in km/s
+	 **/
+	double vRSun(long double jd);
+
+	/** Computes the radial velocity of a source referred to the solar system barycenter 
+	 * from the radial velocity referred to the
+	 * Local Standard of Rest, aka known as VLSR. To compute it we need the coordinates of the
+	 * source the VLSR and the epoch for the source coordinates.
+	 *
+	 * @param vlsr radial velocity of the source referred to the LSR in km/s
+	 * @param jd Epoch expressed as julian day to which the source coordinates refer to.
+	 * @return Radial velocity of the source referred to the barycenter of the solar system in km/s
+	 **/
+	double vHeliocentric(double vlsr, long double jd);
+
+	/** Computes the radial velocity of a source referred to the Local Standard of Rest, also known as VLSR
+	 * from the radial velocity referred to the solar system barycenter 
+	 *
+	 * @param vhelio radial velocity of the source referred to the LSR in km/s
+	 * @param jd Epoch expressed as julian day to which the source coordinates refer to.
+	 * @return Radial velocity of the source referred to the barycenter of the solar system in km/s
+	 **/
+	double vHelioToVlsr(double vhelio, long double jd);
+
+	/** Computes the velocity of any object projected on the direction of the source.
+	 *  @param jd0 Julian day for which we compute the direction of the source
+	 *  @return velocity of the Earth projected on the direction of the source kms-1
+	 */
+	double vREarth(long double jd0);
+	
+	/** Computes the radial velocity of a source referred to the center of the earth 
+	 * from the radial velocity referred to the solar system barycenter
+	 *
+	 * @param vhelio radial velocity of the source referred to the barycenter of the 
+	 *               solar system in km/s
+	 * @param jd     Epoch expressed as julian day to which the source coordinates refer to.
+	 * @return Radial velocity of the source referred to the center of the Earth in km/s
+	 **/
+	double vGeocentric(double vhelio, long double jd);
+
+	/** Computes the radial velocity of a source referred to the solar system barycenter 
+	 * from the velocity referred to the center of the earth 
+	 *
+	 * @param vgeo   radial velocity of the source referred to the center of the Earth
+	 *               [km/s]
+	 * @param jd     Epoch expressed as julian day to which the source coordinates refer to.
+	 * @return Radial velocity of the source referred to the solar system barycenter in km/s
+	 **/
+	double vGeoToVHelio(double vgeo, long double jd);
+
+	/** Computes the velocity of any object (oberver's site) projected on the 
+	 * direction of the source.
+	 *  @param vsite velocity of that object in cartesian coordinates
+	 *  @return velocity of the object projected on the direction of the source kms-1
+	 */
+	double vRSite(double vsite[3]);
+
+	/** Computes the radial velocity of a source referred to the observer site on the surface
+	 * of the earth from the geocentric velovity and the velocity of the site referred to the center
+	 * of the Earth.
+	 *
+	 * @param vgeo radial velocity of the source referred to the center of the earth in km/s
+	 * @param vsite Velocity at which the observer moves referred to the center of the earth.
+	 * @return Radial velocity of the source referred to the observer's site in km/s
+	 **/
+	double vTopocentric(double vgeo, double vsite[3]);
+
+	/** Computes the radial velocity of a source referred to the center of the Earth from 
+	 * the radial velocity referred to an observer site on the surface of the earth 
+	 * 
+	 * @param vtopo radial velocity of the source referred to the observer's site in km/s
+	 * @param vsite Velocity at which the observer moves referred to the center of the earth.
+	 * @return Radial velocity of the source referred the center of the earth in km/s
+	 **/
+	double vTopoToVGeo(double vtopo, double vsite[3]);
 
 ////
 //// 5. Calculating Rise/Set/Transit data.
@@ -401,6 +480,7 @@ public:
 
 	QString constellation( QPtrList<CSegment> &seglist, QPtrList<SkyObject> &cnames ) const;
 
+
 protected:
 /**Precess this SkyPoint's catalog coordinates to the epoch described by the
 	*given KSNumbers object.
