@@ -1,8 +1,8 @@
 /***************************************************************************
  *   ktouchslideline.h                                                     *
  *   -----------------                                                     *
- *   Copyright (C) 2000 by Hvard Friland, 2003 by Andreas Nicolai        *
- *   haavard@users.sourceforge.net                                         *
+ *   Copyright (C) 2000 by Håvard Frøiland, 2004 by Andreas Nicolai        *
+ *   ghorwin@users.sourceforge.net                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -17,10 +17,10 @@
 #include <qpixmap.h>
 #include <kdebug.h>
 
-#include <math.h>
+#include <cmath>
+#include <algorithm>
 
-#include "ktouchsettings.h"
-#include "ktouchmacros.h"
+#include "prefs.h"
 
 // don't use defines here... most of the time they are pure evil :-)
 const int LINE_SPACING          = 2;    // the distance between the teacher and student line
@@ -65,17 +65,18 @@ KTouchSlideLine::~KTouchSlideLine() {
 }
 
 void KTouchSlideLine::applyPreferences() {
-    m_font = KTouchConfig().m_font;
+	// only take font if "override lecture font" is set
+	if (Prefs::overrideLectureFont())
+    	m_font = Prefs::font();
     resizeEvent(NULL); // because we need to recreate the pixmap sizes
     // note: resizeFont() will be called implicitly by resizeEvent()
 }
 
 void KTouchSlideLine::setNewText(const QString& teacherText, const QString& studentText) {
-   if(teacherText[0].direction()==QChar::DirR)
-    m_rightJustify=true;
-   else
-    m_rightJustify=false;
- 
+	if(teacherText[0].direction()==QChar::DirR)
+    	m_rightJustify=true;
+   	else
+    	m_rightJustify=false;
     m_teacherText=teacherText;
     m_studentText=studentText;
     resizeEvent(NULL); // because we need to recreate the pixmap sizes
@@ -86,6 +87,14 @@ void KTouchSlideLine::setStudentText(const QString& text) {
     updateLines();
 }
 
+void KTouchSlideLine::setFont(const QFont& font) {
+	if (Prefs::overrideLectureFont())
+		m_font = Prefs::font();
+	else
+		m_font = font;
+    resizeEvent(NULL); // because we need to recreate the pixmap sizes
+}
+
 
 // *** Public slots
 
@@ -108,7 +117,7 @@ void KTouchSlideLine::slide() {
     if (m_studentPixmap==NULL || m_teacherPixmap==NULL) return;
     // kdDebug() << "[KTouchSlideLine::slide]" << endl;
     // calculate new x positions depending on slide speed
-    double speed = 1.0 + 0.2*KTouchConfig().m_slideSpeed;
+    double speed = 1.0 + 0.2*Prefs::slidingSpeed();
     double m_teacherDX = (m_teacherFrameXEnd - m_teacherFrameX)/speed;
     double m_studentDX = (m_studentFrameXEnd - m_studentFrameX)/speed;
     if (fabs(m_teacherDX)>1.0)  m_teacherFrameX += m_teacherDX;
@@ -170,8 +179,8 @@ void KTouchSlideLine::resizeEvent ( QResizeEvent * ) {
     painter.begin (m_teacherPixmap, this);
     painter.setFont( m_font );
     //painter.setColor( KTouchConfig().m_teacherTextColor );
-    painter.fillRect( m_teacherPixmap->rect(), QBrush(KTouchConfig().m_teacherBackground) );
-    painter.setPen( KTouchConfig().m_teacherTextColor );
+    painter.fillRect( m_teacherPixmap->rect(), QBrush(Prefs::teacherBackgroundColor()) );
+    painter.setPen( Prefs::teacherTextColor() );
     // create a rectangle for the text drawing
     QRect textRect(INNER_MARGIN, 0, w-2*INNER_MARGIN, h);
     if(m_rightJustify==false)
@@ -214,14 +223,14 @@ void KTouchSlideLine::drawCursor() {
      /*the small distance between the beging of the pixmap and the cursor:*/
      int dx=myX/*location of cursor*/ - (HORIZONTAL_MARGIN + m_shift)/*start of pixmap*/;
      
-     myX=(HORIZONTAL_MARGIN + m_shift/*start of pixmap*/)+ m_frameWidth-dx ;
+     myX=(HORIZONTAL_MARGIN + m_shift/*start of pixmap*/)+ m_frameWidth-dx+3 ;
      }
     if (myX>HORIZONTAL_MARGIN && myX<width()-HORIZONTAL_MARGIN)
         p.drawLine(myX, m_cursorYPos, myX, m_cursorYPos + m_cursorHeight);
 }
 
 void KTouchSlideLine::drawEnterChar(QPainter *painter, int cursorPos, int y, int enterWidth) {
-    int gap = min(2,static_cast<int>(0.2*enterWidth));
+    int gap = std::min(2,static_cast<int>(0.2*enterWidth));
     int enterHeight = static_cast<int>(0.4*enterWidth);
     int arrowSize = static_cast<int>(enterWidth/4.0);     // mind the difference between 4 and 4.0
     painter->drawLine(cursorPos+enterWidth, y, cursorPos+enterWidth, y-enterHeight);    // vertical line
@@ -250,26 +259,26 @@ void KTouchSlideLine::updateLines() {
     // now let's draw the students pixmap
     QPainter painter;
     painter.begin (m_studentPixmap, this);
-    if (KTouchConfig().m_useErrorColor) {
+    if (Prefs::colorOnError()) {
         // draw the student line depending on the colour settings
         if (error) {
-            m_cursorBackground = KTouchConfig().m_errorBackground;
+            m_cursorBackground = Prefs::errorBackgroundColor();
             painter.fillRect (m_studentPixmap->rect(), m_cursorBackground);
-            m_cursorColor = KTouchConfig().m_errorTextColor;
+            m_cursorColor = Prefs::errorTextColor();
             painter.setPen( m_cursorColor );
         }
         else {
-            m_cursorBackground = KTouchConfig().m_studentBackground;
+            m_cursorBackground = Prefs::studentBackgroundColor();
             painter.fillRect (m_studentPixmap->rect(), QBrush(m_cursorBackground) );
-            m_cursorColor = KTouchConfig().m_studentTextColor;
+            m_cursorColor = Prefs::studentTextColor();
             painter.setPen( m_cursorColor );
         };
     }
     else {
         // use always student text colors
-        m_cursorColor = KTouchConfig().m_studentTextColor;
+        m_cursorColor = Prefs::studentTextColor();
         painter.setPen( m_cursorColor );
-        m_cursorBackground = KTouchConfig().m_studentBackground;
+        m_cursorBackground = Prefs::studentBackgroundColor();
         painter.fillRect( m_studentPixmap->rect(), QBrush(m_cursorBackground) );
     };
     // draw the text
@@ -298,12 +307,12 @@ void KTouchSlideLine::updateLines() {
     // calculate the relative cursor positions in the output line
     QString typedText = m_teacherText.left(studentLen);
     int typedTextLength=textWidth(fontMetrics, typedText);
-    double CPosFactor = min(1.0, static_cast<double>(typedTextLength)/m_teacherTextWidth);
+    double CPosFactor = std::min(1.0, static_cast<double>(typedTextLength)/m_teacherTextWidth);
     // calculate the local coordinate of the cursor in the teacher line
     int teacherCursorPos = INNER_MARGIN + typedTextLength;
     // now calculate the horizontal offset
     int xDistance = INNER_MARGIN + static_cast<int>( CPosFactor*(allowedWidth-2*INNER_MARGIN-m_enterCharWidth) );
-    m_cursorXPos = HORIZONTAL_MARGIN + m_shift + xDistance + min(2,static_cast<int>(fontMetrics.height()*0.1));
+    m_cursorXPos = HORIZONTAL_MARGIN + m_shift + xDistance + std::min(2,static_cast<int>(fontMetrics.height()*0.1));
     m_teacherFrameXEnd = teacherCursorPos - xDistance;
     m_studentFrameXEnd = studentCursorPos - xDistance;
     painter.end();
