@@ -1,7 +1,5 @@
 /***************************************************************************
 
-    $Id: kvoctraindoc.h 360878 2004-11-06 00:09:28Z hedlund $
-
                          maintain a kvoctrain document
 
     -----------------------------------------------------------------------
@@ -27,11 +25,11 @@
  ***************************************************************************/
 
 #ifndef KVOCTRAINDOC_H
-#define KVOCTRAINDOC_H 
+#define KVOCTRAINDOC_H
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif 
+#endif
 
 #include <qobject.h>
 
@@ -210,7 +208,7 @@
  </conjugation>
 
  <conjugation>        and in entry for definition of tenses of (irreg.) verbs
-  <t n="sipa">       
+  <t n="sipa">
    <s1>go</s1>
    <s2>go</s2>
    <s3f>goes</s3f>
@@ -260,14 +258,14 @@ class kvoctrainDoc : public QObject
   enum FileType { kvd_none, automatic,
                   kvtml,
                   kvtbin,
-                  vt_lex, vt_vcb, csv /*, kvoclearn, qvocab*/ };
+                  vt_lex, vt_vcb, csv, vt_voc /*, kvoclearn, qvocab*/ };
 
   /** Constructor for the fileclass of the application
    *
-   * @param obj              calling object
-   * @param filename         name of file to parse
+   * @param obj calling object
+   * @param url URL of file to parse
    */
-  kvoctrainDoc(QObject* obj, const KURL& url, QString separator, QStringList *lang_order = 0);
+  kvoctrainDoc(QObject* obj, const KURL& url);
 
   /** Destructor for the fileclass of the application */
   ~kvoctrainDoc();
@@ -360,7 +358,7 @@ class kvoctrainDoc : public QObject
    */
   int findIdent (const QString &lang) const;
 
-  /** returns attribute string 
+  /** returns attribute string
    *
    * @param index            number of attribute
    * @result                 string
@@ -426,8 +424,7 @@ class kvoctrainDoc : public QObject
    * @param url     if url is empty (or NULL) actual name is preserved
    * @result         true if successful
    */
-  bool saveAs (QObject *parent, const KURL & url, QString title, FileType ft, const QString &separator,
-    QStringList *lang_order = 0);
+  bool saveAs (QObject *parent, const KURL & url, QString title, FileType ft);
 
   /** returns count of entries
    */
@@ -695,8 +692,8 @@ protected:
   bool saveTypeNameLex   (QTextStream& os);
   bool loadTypeNameLex   (QTextStream& is);
 
-  bool saveToCsv     (QTextStream& os, QString &title, const QString &separator, QStringList *lang_order);
-  bool loadFromCsv   (QTextStream& is, QString &separator, QStringList *lang_order);
+  bool saveToCsv     (QTextStream& os, QString &title);
+  bool loadFromCsv   (QTextStream& is);
   bool loadLessonCsv (QTextStream& is);
   bool saveLessonCsv (QTextStream& os);
   bool saveTypeNameCsv   (QTextStream& os);
@@ -708,6 +705,7 @@ protected:
   bool loadLessonVcb (QTextStream &is);
   bool saveToVcb (QTextStream& os, QString &title);
   bool loadFromVcb (QTextStream& is);
+  bool loadFromVoc(QTextStream& is);
   void errorVcb (int line, const QString &text );
 
  private:
