@@ -1,7 +1,5 @@
 /* -*- C++ -*-
 
-  $Id: XmlWriter.cpp 237589 2003-07-17 12:48:23Z binner $
-
   This file is part of KIllustrator.
   Copyright (C) 1998 Kai-Uwe Sattler (kus@iti.cs.uni-magdeburg.de)
 
@@ -11,7 +9,7 @@
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU Library General Public License as
-  published by  
+  published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.
 
@@ -19,10 +17,10 @@
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.
-  
+
   You should have received a copy of the GNU Library General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #include "XmlWriter.h"
@@ -52,7 +50,7 @@ void XmlWriter::startTag (KOXML_STRING id, bool closeIt, bool empty, bool eol)
   }
 
   if (closeIt) {
-    if (empty) 
+    if (empty)
       strm << "/";
     strm << ">";
     if (eol || autoendl) {
@@ -62,7 +60,7 @@ void XmlWriter::startTag (KOXML_STRING id, bool closeIt, bool empty, bool eol)
     }
   }
 }
- 
+
 
 void XmlWriter::endTag (KOXML_STRING id, bool eol)
 {
